<?xml version="1.0" encoding="utf-8"?>
<!DOCTYPE TS>
<TS version="2.1" language="sq">
<context>
    <name>AppendDialog</name>
    <message>
        <location filename="../src/source/dialog/popupdialog.cpp" line="432"/>
        <source>Add files to the current archive</source>
        <translation>Shtoni kartela te arkivi i tanishëm</translation>
    </message>
    <message>
        <location filename="../src/source/dialog/popupdialog.cpp" line="437"/>
        <source>Use password</source>
        <translation>Përdor fjalëkalim</translation>
    </message>
</context>
<context>
    <name>CalculateSizeThread</name>
    <message>
        <location filename="../src/source/common/calculatesizethread.cpp" line="68"/>
        <location filename="../src/source/common/calculatesizethread.cpp" line="136"/>
        <source>The original file of %1 does not exist, please check and try again</source>
        <translation>Kartela origjinale e %1 s’ekziston, ju lutemi, kontrolloni dhe riprovoni</translation>
    </message>
    <message>
        <location filename="../src/source/common/calculatesizethread.cpp" line="70"/>
        <location filename="../src/source/common/calculatesizethread.cpp" line="138"/>
        <source>%1 does not exist on the disk, please check and try again</source>
        <translation>%1 s’ekziston në disk, ju lutemi, kontrolloni dhe riprovoni</translation>
    </message>
    <message>
        <location filename="../src/source/common/calculatesizethread.cpp" line="79"/>
        <location filename="../src/source/common/calculatesizethread.cpp" line="147"/>
        <source>You do not have permission to compress %1</source>
        <translation>S’keni leje për të ngjeshur %1</translation>
    </message>
</context>
<context>
    <name>CommentProgressDialog</name>
    <message>
        <location filename="../src/source/dialog/progressdialog.cpp" line="234"/>
        <source>Updating the comment...</source>
        <translation>Po përditësohet komenti…</translation>
    </message>
</context>
<context>
    <name>CompressPage</name>
    <message>
        <location filename="../src/source/page/compresspage.cpp" line="76"/>
        <source>Next</source>
        <translation>Pasuesja</translation>
    </message>
    <message>
        <location filename="../src/source/page/compresspage.cpp" line="117"/>
        <source>Please add files</source>
        <translation>Ju lutemi, shtoni kartela</translation>
    </message>
    <message>
        <location filename="../src/source/page/compresspage.cpp" line="117"/>
        <source>OK</source>
        <comment>button</comment>
        <translation>OK</translation>
    </message>
</context>
<context>
    <name>CompressSettingPage</name>
    <message>
        <location filename="../src/source/page/compresssettingpage.cpp" line="143"/>
        <location filename="../src/source/page/compresssettingpage.cpp" line="226"/>
        <source>New Archive</source>
        <translation>Arkiv i Ri</translation>
    </message>
    <message>
        <location filename="../src/source/page/compresssettingpage.cpp" line="204"/>
        <source>Advanced Options</source>
        <translation>Mundësi të Mëtejshme</translation>
    </message>
    <message>
        <location filename="../src/source/page/compresssettingpage.cpp" line="208"/>
        <source>Compression method</source>
        <translation>Metodë ngjeshjeje</translation>
    </message>
    <message>
        <location filename="../src/source/page/compresssettingpage.cpp" line="211"/>
        <source>Encrypt the archive</source>
        <translation>Fshehtëzoje arkivin</translation>
    </message>
    <message>
        <location filename="../src/source/page/compresssettingpage.cpp" line="213"/>
        <source>CPU threads</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../src/source/page/compresssettingpage.cpp" line="215"/>
        <source>Encrypt the file list too</source>
        <translation>Fshehtëzo edhe listën e kartelave</translation>
    </message>
    <message>
        <location filename="../src/source/page/compresssettingpage.cpp" line="217"/>
        <source>Split to volumes</source>
        <translation>Ndaje në vëllime</translation>
    </message>
    <message>
        <location filename="../src/source/page/compresssettingpage.cpp" line="219"/>
        <source>Comment</source>
        <translation>Koment</translation>
    </message>
    <message>
        <location filename="../src/source/page/compresssettingpage.cpp" line="221"/>
        <source>Compress</source>
        <comment>button</comment>
        <translation>Ngjeshe</translation>
    </message>
    <message>
        <location filename="../src/source/page/compresssettingpage.cpp" line="240"/>
        <source>Store</source>
        <translation>Depozitoje</translation>
    </message>
    <message>
        <location filename="../src/source/page/compresssettingpage.cpp" line="240"/>
        <source>Fastest</source>
        <translation>Më e shpejta</translation>
    </message>
    <message>
        <location filename="../src/source/page/compresssettingpage.cpp" line="240"/>
        <source>Fast</source>
        <translation>E shpejtë</translation>
    </message>
    <message>
        <location filename="../src/source/page/compresssettingpage.cpp" line="240"/>
        <source>Normal</source>
        <translation>Normale</translation>
    </message>
    <message>
        <location filename="../src/source/page/compresssettingpage.cpp" line="240"/>
        <source>Good</source>
        <translation>E mirë</translation>
    </message>
    <message>
        <location filename="../src/source/page/compresssettingpage.cpp" line="240"/>
        <source>Best</source>
        <translation>Më e mira</translation>
    </message>
    <message>
        <location filename="../src/source/page/compresssettingpage.cpp" line="247"/>
        <source>Single thread</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../src/source/page/compresssettingpage.cpp" line="247"/>
        <source>2 threads</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../src/source/page/compresssettingpage.cpp" line="247"/>
        <source>4 threads</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../src/source/page/compresssettingpage.cpp" line="247"/>
        <source>8 threads</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../src/source/page/compresssettingpage.cpp" line="257"/>
        <source>Support zip, 7z type only</source>
        <translation>Mbulo zip, vetëm të llojit 7z</translation>
    </message>
    <message>
        <location filename="../src/source/page/compresssettingpage.cpp" line="260"/>
        <source>Support 7z type only</source>
        <translation>Mbulo vetëm llojin 7z</translation>
    </message>
    <message>
        <location filename="../src/source/page/compresssettingpage.cpp" line="272"/>
        <source>Enter up to %1 characters</source>
        <translation>Jepni deri %1 shenja</translation>
    </message>
    <message>
        <location filename="../src/source/page/compresssettingpage.cpp" line="293"/>
        <source>Name</source>
        <translation>Emër</translation>
    </message>
    <message>
        <location filename="../src/source/page/compresssettingpage.cpp" line="294"/>
        <source>Save to</source>
        <translation>Ruaje te</translation>
    </message>
    <message>
        <location filename="../src/source/page/compresssettingpage.cpp" line="483"/>
        <source>Invalid file name</source>
        <translation>Emër i pavlefshëm kartele</translation>
    </message>
    <message>
        <location filename="../src/source/page/compresssettingpage.cpp" line="489"/>
        <source>Please enter the path</source>
        <translation>Ju lutemi, jepni shtegun</translation>
    </message>
    <message>
        <location filename="../src/source/page/compresssettingpage.cpp" line="494"/>
        <source>The path does not exist, please retry</source>
        <translation>Shtegu s’ekziston, ju lutemi, riprovoni</translation>
    </message>
    <message>
        <location filename="../src/source/page/compresssettingpage.cpp" line="499"/>
        <source>You do not have permission to save files here, please change and retry</source>
        <translation>S’keni leje të ruani kartela këtu, ju lutemi, ndryshoni lejet dhe riprovoni</translation>
    </message>
    <message>
        <location filename="../src/source/page/compresssettingpage.cpp" line="507"/>
        <source>Too many volumes, please change and retry</source>
        <translation>Shumë vëllime, ju lutemi, ndryshojini dhe riprovoni</translation>
    </message>
    <message>
        <location filename="../src/source/page/compresssettingpage.cpp" line="516"/>
        <location filename="../src/source/page/compresssettingpage.cpp" line="544"/>
        <source>%1 does not exist on the disk, please check and try again</source>
        <translation>%1 s’ekziston te disku, ju lutemi, kontrolloni dhe riprovoni</translation>
    </message>
    <message>
        <location filename="../src/source/page/compresssettingpage.cpp" line="522"/>
        <location filename="../src/source/page/compresssettingpage.cpp" line="551"/>
        <source>You do not have permission to compress %1</source>
        <translation>S’keni leje të ngjishni %1</translation>
    </message>
    <message>
        <location filename="../src/source/page/compresssettingpage.cpp" line="542"/>
        <source>The original file of %1 does not exist, please check and try again</source>
        <translation>Kartela origjinale %1 s’ekziston, ju lutemi, kontrolloni dhe riprovoni</translation>
    </message>
    <message>
        <location filename="../src/source/page/compresssettingpage.cpp" line="577"/>
        <source>OK</source>
        <comment>button</comment>
        <translation>OK</translation>
    </message>
    <message>
        <location filename="../src/source/page/compresssettingpage.cpp" line="783"/>
        <source>Cancel</source>
        <comment>button</comment>
        <translation>Anuloje</translation>
    </message>
    <message>
        <location filename="../src/source/page/compresssettingpage.cpp" line="783"/>
        <source>Replace</source>
        <comment>button</comment>
        <translation>Zëvendësoje</translation>
    </message>
    <message>
        <location filename="../src/source/page/compresssettingpage.cpp" line="691"/>
        <source>Total size: %1</source>
        <translation>Madhësi gjithsej: %1</translation>
    </message>
    <message>
        <location filename="../src/source/page/compresssettingpage.cpp" line="711"/>
        <source>The name is the same as that of the compressed archive, please use another one</source>
        <translation>Emri është i njëjtë me atë të arkivit të ngjeshur, ju lutemi, përdorni një tjetër</translation>
    </message>
    <message>
        <location filename="../src/source/page/compresssettingpage.cpp" line="719"/>
        <source>The password for ZIP volumes cannot be in Chinese</source>
        <translation>Fjalëkalimi për vëllimet ZIP s’mund të jetë në kinezçe</translation>
    </message>
    <message>
        <location filename="../src/source/page/compresssettingpage.cpp" line="783"/>
        <source>Another file with the same name already exists, replace it?</source>
        <translation>Ka tashmë një kartelë me po atë emër, të zëvendësohet?</translation>
    </message>
    <message>
        <location filename="../src/source/page/compresssettingpage.cpp" line="823"/>
        <source>Only Chinese and English characters and some symbols are supported</source>
        <translation>Mbulohen vetëm shenja të gjuhës kineze dhe të anglishtes, si dhe disa simbole</translation>
    </message>
</context>
<context>
    <name>CompressView</name>
    <message>
        <location filename="../src/source/tree/compressview.cpp" line="284"/>
        <source>Open</source>
        <translation>Përzgjidhni kartelën</translation>
    </message>
    <message>
        <location filename="../src/source/tree/compressview.cpp" line="298"/>
        <source>Delete</source>
        <translation>Fshije</translation>
    </message>
    <message>
        <location filename="../src/source/tree/compressview.cpp" line="301"/>
        <source>Open with</source>
        <translation>Hape me</translation>
    </message>
    <message>
        <location filename="../src/source/tree/compressview.cpp" line="305"/>
        <location filename="../src/source/tree/compressview.cpp" line="407"/>
        <source>Select default program</source>
        <translation>Përzgjidhni program parazgjedhje</translation>
    </message>
    <message>
        <location filename="../src/source/tree/compressview.cpp" line="348"/>
        <source>It will permanently delete the file(s). Are you sure you want to continue?</source>
        <translation>Do të fshijë përgjithnjë kartelën(at). Jeni i sigurt se doni të vazhdohet?</translation>
    </message>
    <message>
        <location filename="../src/source/tree/compressview.cpp" line="348"/>
        <location filename="../src/source/tree/compressview.cpp" line="381"/>
        <source>Cancel</source>
        <comment>button</comment>
        <translation>Anuloje</translation>
    </message>
    <message>
        <location filename="../src/source/tree/compressview.cpp" line="348"/>
        <source>Confirm</source>
        <comment>button</comment>
        <translation>Ripohojeni</translation>
    </message>
    <message>
        <location filename="../src/source/tree/compressview.cpp" line="382"/>
        <source>Add</source>
        <comment>button</comment>
        <translation>Shtoje</translation>
    </message>
    <message>
        <location filename="../src/source/tree/compressview.cpp" line="380"/>
        <source>Do you want to add the archive to the list or open it in new window?</source>
        <translation>Doni të shtohet arkivi te lista apo të hapet në një dritare të re?</translation>
    </message>
    <message>
        <location filename="../src/source/tree/compressview.cpp" line="383"/>
        <source>Open in new window</source>
        <translation>Hape në dritare të re</translation>
    </message>
</context>
<context>
    <name>ConvertDialog</name>
    <message>
        <location filename="../src/source/dialog/popupdialog.cpp" line="306"/>
        <source>Changes to archives in this file type are not supported. Please convert the archive format to save the changes.</source>
        <translation>Nuk mbulohet ndryshime te arkiva me këtë lloj kartelash. Që të ruhen ndryshimet, ju lutemi, shndërroni formatin e arkivit.</translation>
    </message>
    <message>
        <location filename="../src/source/dialog/popupdialog.cpp" line="314"/>
        <source>Convert the format to:</source>
        <translation>Shndërroje formatin në:</translation>
    </message>
    <message>
        <location filename="../src/source/dialog/popupdialog.cpp" line="338"/>
        <source>Cancel</source>
        <comment>button</comment>
        <translation>Anuloje</translation>
    </message>
    <message>
        <location filename="../src/source/dialog/popupdialog.cpp" line="339"/>
        <source>Convert</source>
        <comment>button</comment>
        <translation>Shndërroje</translation>
    </message>
</context>
<context>
    <name>DataModel</name>
    <message>
        <location filename="../src/source/tree/datamodel.cpp" line="70"/>
        <source>item(s)</source>
        <translation>objekt(e)</translation>
    </message>
</context>
<context>
    <name>FailurePage</name>
    <message>
        <location filename="../src/source/page/failurepage.cpp" line="87"/>
        <source>Extraction failed</source>
        <comment>解压失败</comment>
        <translation>Përftimi dështoi</translation>
    </message>
    <message>
        <location filename="../src/source/page/failurepage.cpp" line="100"/>
        <source>Damaged file, unable to extract</source>
        <translation>Kartelë e dëmtuar, s’arrihet të përftohet</translation>
    </message>
    <message>
        <location filename="../src/source/page/failurepage.cpp" line="105"/>
        <source>Retry</source>
        <comment>button</comment>
        <translation>Riprovoni</translation>
    </message>
    <message>
        <location filename="../src/source/page/failurepage.cpp" line="108"/>
        <source>Back</source>
        <translation>Mbrapsht</translation>
    </message>
</context>
<context>
    <name>HomePage</name>
    <message>
        <location filename="../src/source/page/homepage.cpp" line="56"/>
        <source>Drag file or folder here</source>
        <translation>Tërhiqni këtu kartelë ose dosje</translation>
    </message>
    <message>
        <location filename="../src/source/page/homepage.cpp" line="58"/>
        <source>Select File</source>
        <translation>Përzgjidhni Kartelë</translation>
    </message>
</context>
<context>
    <name>LoadCorruptQuery</name>
    <message>
        <location filename="../3rdparty/interface/queries.cpp" line="525"/>
        <source>The archive is damaged</source>
        <translation>Arkivi është i dëmtuar</translation>
    </message>
    <message>
        <location filename="../3rdparty/interface/queries.cpp" line="528"/>
        <source>Open as read-only</source>
        <translation>Hape si vetëm-për-lexim</translation>
    </message>
    <message>
        <location filename="../3rdparty/interface/queries.cpp" line="529"/>
        <source>Cancel</source>
        <comment>button</comment>
        <translation>Anuloje</translation>
    </message>
</context>
<context>
    <name>LoadingPage</name>
    <message>
        <location filename="../src/source/page/loadingpage.cpp" line="65"/>
        <source>Loading, please wait...</source>
        <translation>Po ngarkohet, ju lutemi, pritni…</translation>
    </message>
</context>
<context>
    <name>Main</name>
    <message>
        <location filename="../src/main.cpp" line="60"/>
        <location filename="../src/main.cpp" line="61"/>
        <source>Archive Manager</source>
        <translation>Përgjegjës Arkivash</translation>
    </message>
    <message>
        <location filename="../src/main.cpp" line="62"/>
        <source>Archive Manager is a fast and lightweight application for creating and extracting archives.</source>
        <translation>Përgjegjësi i Kartelave është një aplikacion i shpejtë dhe i peshës së lehtë për krijim dhe përftim arkivash.</translation>
    </message>
</context>
<context>
    <name>MainWindow</name>
    <message>
        <location filename="../src/source/mainwindow.cpp" line="172"/>
        <location filename="../src/source/mainwindow.cpp" line="191"/>
        <location filename="../src/source/mainwindow.cpp" line="440"/>
        <source>Open file</source>
        <translation>Hap kartelë</translation>
    </message>
    <message>
        <location filename="../src/source/mainwindow.cpp" line="173"/>
        <source>Settings</source>
        <translation>Rregullime</translation>
    </message>
    <message>
        <location filename="../src/source/mainwindow.cpp" line="294"/>
        <location filename="../src/source/mainwindow.cpp" line="304"/>
        <source>Create New Archive</source>
        <translation>Krijoni Arkiv të Ri</translation>
    </message>
    <message>
        <location filename="../src/source/mainwindow.cpp" line="345"/>
        <source>Converting</source>
        <translation>Po shndërrohet</translation>
    </message>
    <message>
        <location filename="../src/source/mainwindow.cpp" line="352"/>
        <source>Updating comments</source>
        <translation>Po përditësohen komentet</translation>
    </message>
    <message>
        <location filename="../src/source/mainwindow.cpp" line="523"/>
        <location filename="../src/source/mainwindow.cpp" line="2068"/>
        <location filename="../src/source/mainwindow.cpp" line="2090"/>
        <location filename="../src/source/mainwindow.cpp" line="2115"/>
        <source>Plugin error</source>
        <translation>Gabim shtojce</translation>
    </message>
    <message>
        <location filename="../src/source/mainwindow.cpp" line="1302"/>
        <source>Adding successful</source>
        <translation>Shtim i suksesshëm</translation>
    </message>
    <message>
        <location filename="../src/source/mainwindow.cpp" line="1334"/>
        <location filename="../src/source/mainwindow.cpp" line="2139"/>
        <source>No data in it</source>
        <translation>S’ka të dhëna në të</translation>
    </message>
    <message>
        <location filename="../src/source/mainwindow.cpp" line="1522"/>
        <source>Adding canceled</source>
        <translation>Shtimi u anulua</translation>
    </message>
    <message>
        <location filename="../src/source/mainwindow.cpp" line="1620"/>
        <source>Adding failed</source>
        <translation>Shtimi dështoi</translation>
    </message>
    <message>
        <location filename="../src/source/mainwindow.cpp" line="1673"/>
        <source>Extraction failed: the file name is too long</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../src/source/mainwindow.cpp" line="1700"/>
        <location filename="../src/source/mainwindow.cpp" line="2135"/>
        <source>Failed to create &quot;%1&quot;</source>
        <translation>S’u arrit të krijohet &quot;%1&quot;</translation>
    </message>
    <message>
        <location filename="../src/source/mainwindow.cpp" line="1822"/>
        <source>Open failed: the file name is too long</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../src/source/mainwindow.cpp" line="2041"/>
        <source>Compression successful</source>
        <translation>Ngjeshje e suksesshme</translation>
    </message>
    <message>
        <location filename="../src/source/mainwindow.cpp" line="2047"/>
        <source>The file name is too long, so the first 60 characters have been intercepted as the file name.</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../src/source/mainwindow.cpp" line="2076"/>
        <location filename="../src/source/mainwindow.cpp" line="2143"/>
        <source>Insufficient disk space</source>
        <translation>Hapësirë e pamjaftueshme disku</translation>
    </message>
    <message>
        <location filename="../src/source/mainwindow.cpp" line="2102"/>
        <location filename="../src/source/mainwindow.cpp" line="2123"/>
        <source>Some volumes are missing</source>
        <translation>Mungojnë disa vëllime</translation>
    </message>
    <message>
        <location filename="../src/source/mainwindow.cpp" line="2127"/>
        <source>Wrong password, please retry</source>
        <translation>Fjalëkalim i gabuar, ju lutemi, riprovoni</translation>
    </message>
    <message>
        <location filename="../src/source/mainwindow.cpp" line="2131"/>
        <location filename="../src/source/mainwindow.cpp" line="2155"/>
        <source>The file name is too long. Keep the name within 60 characters please.</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../src/source/mainwindow.cpp" line="2152"/>
        <source>Conversion failed</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../src/source/mainwindow.cpp" line="2290"/>
        <source>Select file</source>
        <translation>Përzgjidhni kartelë</translation>
    </message>
    <message>
        <location filename="../src/source/mainwindow.cpp" line="3102"/>
        <source>Enter up to %1 characters</source>
        <translation>Jepni deri %1 shenja</translation>
    </message>
    <message>
        <location filename="../src/source/mainwindow.cpp" line="196"/>
        <location filename="../src/source/mainwindow.cpp" line="2978"/>
        <source>File info</source>
        <translation>Të dhëna kartele</translation>
    </message>
    <message>
        <location filename="../src/source/mainwindow.cpp" line="1411"/>
        <source>Do you want to delete the archive?</source>
        <translation>Doni të fshihet arkivi?</translation>
    </message>
    <message>
        <location filename="../src/source/mainwindow.cpp" line="553"/>
        <source>%1 was changed on the disk, please import it again.</source>
        <translation>%1 ndryshoi në disk, ju lutemi, riimportojeni.</translation>
    </message>
    <message>
        <location filename="../src/source/mainwindow.cpp" line="73"/>
        <source>Archive Manager</source>
        <translation>Përgjegjës Arkivash</translation>
    </message>
    <message>
        <location filename="../src/source/mainwindow.cpp" line="129"/>
        <source>You do not have permission to save files here, please change and retry</source>
        <translation>S’keni leje të ruani kartela këtu, ju lutemi, ndryshoni lejet dhe riprovoni</translation>
    </message>
    <message>
        <location filename="../src/source/mainwindow.cpp" line="317"/>
        <source>Adding files to %1</source>
        <translation>Po shtohen kartela te %1</translation>
    </message>
    <message>
        <location filename="../src/source/mainwindow.cpp" line="324"/>
        <source>Compressing</source>
        <translation>Po ngjishen</translation>
    </message>
    <message>
        <location filename="../src/source/mainwindow.cpp" line="331"/>
        <source>Extracting</source>
        <translation>Po përftohet</translation>
    </message>
    <message>
        <location filename="../src/source/mainwindow.cpp" line="338"/>
        <source>Deleting</source>
        <translation>Po fshihet</translation>
    </message>
    <message>
        <location filename="../src/source/mainwindow.cpp" line="443"/>
        <source>Back</source>
        <translation>Mbrapsht</translation>
    </message>
    <message>
        <location filename="../src/source/mainwindow.cpp" line="513"/>
        <location filename="../src/source/mainwindow.cpp" line="2802"/>
        <source>Loading, please wait...</source>
        <translation>Po ngarkohet, ju lutemi, pritni…</translation>
    </message>
    <message>
        <location filename="../src/source/mainwindow.cpp" line="586"/>
        <source>Are you sure you want to stop the ongoing task?</source>
        <translation>Jeni i sigurt se doni të ndalet akti në xhirim e sipër?</translation>
    </message>
    <message>
        <location filename="../src/source/mainwindow.cpp" line="1308"/>
        <location filename="../src/source/mainwindow.cpp" line="1434"/>
        <source>Updating, please wait...</source>
        <translation>Po përditësohet, ju lutemi, pritni…</translation>
    </message>
    <message>
        <location filename="../src/source/mainwindow.cpp" line="1695"/>
        <source>File name too long</source>
        <translation>Emër kartele shumë i gjatë</translation>
    </message>
    <message>
        <location filename="../src/source/mainwindow.cpp" line="2072"/>
        <source>Failed to create file</source>
        <translation>S’u arrit të krijohet kartelë</translation>
    </message>
    <message>
        <location filename="../src/source/mainwindow.cpp" line="2065"/>
        <source>Compression failed</source>
        <translation>Ngjeshja dështoi</translation>
    </message>
    <message>
        <location filename="../src/source/mainwindow.cpp" line="2400"/>
        <source>Replace</source>
        <comment>button</comment>
        <translation>Zëvendësoje</translation>
    </message>
    <message>
        <location filename="../src/source/mainwindow.cpp" line="2464"/>
        <source>Find directory</source>
        <translation>Gjej drejtori</translation>
    </message>
    <message>
        <location filename="../src/source/mainwindow.cpp" line="2087"/>
        <source>Open failed</source>
        <translation>Hapja dështoi</translation>
    </message>
    <message>
        <location filename="../src/source/mainwindow.cpp" line="1616"/>
        <location filename="../src/source/mainwindow.cpp" line="1690"/>
        <location filename="../src/source/mainwindow.cpp" line="1765"/>
        <location filename="../src/source/mainwindow.cpp" line="1820"/>
        <location filename="../src/source/mainwindow.cpp" line="2098"/>
        <source>Wrong password</source>
        <translation>Fjalëkalim i gabuar</translation>
    </message>
    <message>
        <location filename="../src/source/mainwindow.cpp" line="626"/>
        <location filename="../src/source/mainwindow.cpp" line="659"/>
        <source>The file format is not supported by Archive Manager</source>
        <translation>Formati i kartelës nuk mbulohet nga Përgjegjësi i Arkivave</translation>
    </message>
    <message>
        <location filename="../src/source/mainwindow.cpp" line="129"/>
        <location filename="../src/source/mainwindow.cpp" line="461"/>
        <location filename="../src/source/mainwindow.cpp" line="523"/>
        <location filename="../src/source/mainwindow.cpp" line="556"/>
        <location filename="../src/source/mainwindow.cpp" line="611"/>
        <location filename="../src/source/mainwindow.cpp" line="617"/>
        <location filename="../src/source/mainwindow.cpp" line="626"/>
        <location filename="../src/source/mainwindow.cpp" line="666"/>
        <location filename="../src/source/mainwindow.cpp" line="1334"/>
        <location filename="../src/source/mainwindow.cpp" line="2271"/>
        <location filename="../src/source/mainwindow.cpp" line="2558"/>
        <location filename="../src/source/mainwindow.cpp" line="2722"/>
        <source>OK</source>
        <comment>button</comment>
        <translation>OK</translation>
    </message>
    <message>
        <location filename="../src/source/mainwindow.cpp" line="461"/>
        <location filename="../src/source/mainwindow.cpp" line="617"/>
        <source>You do not have permission to load %1</source>
        <translation>S’keni leje të ngarkoni%1</translation>
    </message>
    <message>
        <location filename="../src/source/mainwindow.cpp" line="586"/>
        <location filename="../src/source/mainwindow.cpp" line="1411"/>
        <location filename="../src/source/mainwindow.cpp" line="2400"/>
        <location filename="../src/source/mainwindow.cpp" line="2824"/>
        <source>Cancel</source>
        <comment>button</comment>
        <translation>Anuloje</translation>
    </message>
    <message>
        <location filename="../src/source/mainwindow.cpp" line="586"/>
        <location filename="../src/source/mainwindow.cpp" line="1411"/>
        <source>Confirm</source>
        <comment>button</comment>
        <translation>Ripohojeni</translation>
    </message>
    <message>
        <location filename="../src/source/mainwindow.cpp" line="611"/>
        <source>No such file or directory</source>
        <translation>S’ka kartelë ose drejtori të tillë</translation>
    </message>
    <message>
        <location filename="../src/source/mainwindow.cpp" line="1350"/>
        <source>Extraction successful</source>
        <comment>提取成功</comment>
        <translation>Përftim i suksesshëm</translation>
    </message>
    <message>
        <location filename="../src/source/mainwindow.cpp" line="1543"/>
        <source>Extraction canceled</source>
        <comment>取消提取</comment>
        <translation>Përftimi u anulua</translation>
    </message>
    <message>
        <location filename="../src/source/mainwindow.cpp" line="1685"/>
        <location filename="../src/source/mainwindow.cpp" line="1760"/>
        <location filename="../src/source/mainwindow.cpp" line="2094"/>
        <location filename="../src/source/mainwindow.cpp" line="2119"/>
        <source>The archive is damaged</source>
        <translation>Arkivi është i dëmtuar</translation>
    </message>
    <message>
        <location filename="../src/source/mainwindow.cpp" line="2045"/>
        <source>Extraction successful</source>
        <comment>解压成功</comment>
        <translation>Përftim i suksesshëm</translation>
    </message>
    <message>
        <location filename="../src/source/mainwindow.cpp" line="2051"/>
        <source>Conversion successful</source>
        <translation>Shndërrim i suksesshëm</translation>
    </message>
    <message>
        <location filename="../src/source/mainwindow.cpp" line="2112"/>
        <source>Extraction failed</source>
        <comment>解压失败</comment>
        <translation>Përftimi dështoi</translation>
    </message>
    <message>
        <location filename="../src/source/mainwindow.cpp" line="2282"/>
        <source>Close</source>
        <translation>Mbylle</translation>
    </message>
    <message>
        <location filename="../src/source/mainwindow.cpp" line="2286"/>
        <source>Help</source>
        <translation>Ndihmë</translation>
    </message>
    <message>
        <location filename="../src/source/mainwindow.cpp" line="2294"/>
        <source>Delete</source>
        <translation>Fshije</translation>
    </message>
    <message>
        <location filename="../src/source/mainwindow.cpp" line="2302"/>
        <source>Display shortcuts</source>
        <translation>Shfaq shkurtore</translation>
    </message>
    <message>
        <location filename="../src/source/mainwindow.cpp" line="2314"/>
        <source>Shortcuts</source>
        <translation>Shkurtore</translation>
    </message>
    <message>
        <location filename="../src/source/mainwindow.cpp" line="2392"/>
        <source>The name is the same as that of the compressed archive, please use another one</source>
        <translation>Emri është i njëjti me atë të arkivit të ngjeshur, ju lutemi, përdorni një tjetër</translation>
    </message>
    <message>
        <location filename="../src/source/mainwindow.cpp" line="2400"/>
        <source>Another file with the same name already exists, replace it?</source>
        <translation>Ka tashmë një kartelë me po atë emër, të zëvendësohet?</translation>
    </message>
    <message>
        <location filename="../src/source/mainwindow.cpp" line="2543"/>
        <source>You cannot add the archive to itself</source>
        <translation>S’mund t’i shtoni arkivit vetveten</translation>
    </message>
    <message>
        <location filename="../src/source/mainwindow.cpp" line="2558"/>
        <source>You cannot add files to archives in this file type</source>
        <translation>S’mund të shtoni kartela të këtij lloji te arkiva</translation>
    </message>
    <message>
        <location filename="../src/source/mainwindow.cpp" line="2824"/>
        <source>Update</source>
        <comment>button</comment>
        <translation>Përditësoje</translation>
    </message>
    <message>
        <location filename="../src/source/mainwindow.cpp" line="3002"/>
        <source>Basic info</source>
        <translation>Të dhëna bazë</translation>
    </message>
    <message>
        <location filename="../src/source/mainwindow.cpp" line="3018"/>
        <source>Size</source>
        <translation>Madhësi</translation>
    </message>
    <message>
        <location filename="../src/source/mainwindow.cpp" line="3019"/>
        <source>Type</source>
        <translation>Lloj</translation>
    </message>
    <message>
        <location filename="../src/source/mainwindow.cpp" line="3020"/>
        <source>Location</source>
        <translation>Vendndodhje</translation>
    </message>
    <message>
        <location filename="../src/source/mainwindow.cpp" line="3021"/>
        <source>Time created</source>
        <translation>Kohë kur u krijua</translation>
    </message>
    <message>
        <location filename="../src/source/mainwindow.cpp" line="3022"/>
        <source>Time accessed</source>
        <translation>Kohë kur u përdor</translation>
    </message>
    <message>
        <location filename="../src/source/mainwindow.cpp" line="3023"/>
        <source>Time modified</source>
        <translation>Kohë ndryshimi</translation>
    </message>
    <message>
        <location filename="../src/source/mainwindow.cpp" line="3033"/>
        <source>Archive</source>
        <translation>Arkiv</translation>
    </message>
    <message>
        <location filename="../src/source/mainwindow.cpp" line="3064"/>
        <source>Comment</source>
        <translation>Koment</translation>
    </message>
    <message>
        <location filename="../src/source/mainwindow.cpp" line="656"/>
        <source>Please check the file association type in the settings of Archive Manager</source>
        <translation>Ju lutemi, kontrolloni llojin e përshoqërimit të kartelës te rregullimet e Përgjegjësit të Arkivave</translation>
    </message>
    <message>
        <location filename="../src/source/mainwindow.cpp" line="2271"/>
        <source>The archive was changed on the disk, please import it again.</source>
        <translation>Arkivi ndryshoi në disk, ju lutemi, riimportojeni.</translation>
    </message>
</context>
<context>
    <name>MimeTypeDisplayManager</name>
    <message>
        <location filename="../src/source/common/mimetypedisplaymanager.cpp" line="46"/>
        <source>Directory</source>
        <translation>Drejtori</translation>
    </message>
    <message>
        <location filename="../src/source/common/mimetypedisplaymanager.cpp" line="47"/>
        <source>Application</source>
        <translation>Aplikacion</translation>
    </message>
    <message>
        <location filename="../src/source/common/mimetypedisplaymanager.cpp" line="48"/>
        <source>Video</source>
        <translation>Video</translation>
    </message>
    <message>
        <location filename="../src/source/common/mimetypedisplaymanager.cpp" line="49"/>
        <source>Audio</source>
        <translation>Audio</translation>
    </message>
    <message>
        <location filename="../src/source/common/mimetypedisplaymanager.cpp" line="50"/>
        <source>Image</source>
        <translation>Figurë</translation>
    </message>
    <message>
        <location filename="../src/source/common/mimetypedisplaymanager.cpp" line="51"/>
        <source>Archive</source>
        <translation>Arkiv</translation>
    </message>
    <message>
        <location filename="../src/source/common/mimetypedisplaymanager.cpp" line="53"/>
        <source>Executable</source>
        <translation>E ekzekutueshme</translation>
    </message>
    <message>
        <location filename="../src/source/common/mimetypedisplaymanager.cpp" line="52"/>
        <source>Document</source>
        <translation>Dokument</translation>
    </message>
    <message>
        <location filename="../src/source/common/mimetypedisplaymanager.cpp" line="54"/>
        <source>Backup file</source>
        <translation>Kartelë kopjeruajtje</translation>
    </message>
    <message>
        <location filename="../src/source/common/mimetypedisplaymanager.cpp" line="55"/>
        <source>Unknown</source>
        <translation>E panjohur</translation>
    </message>
</context>
<context>
    <name>OpenWithDialog</name>
    <message>
        <location filename="../src/source/dialog/openwithdialog/openwithdialog.cpp" line="280"/>
        <source>Open with</source>
        <translation>Hape me</translation>
    </message>
    <message>
        <location filename="../src/source/dialog/openwithdialog/openwithdialog.cpp" line="300"/>
        <source>Add other programs</source>
        <translation>Shtoni programe të tjera</translation>
    </message>
    <message>
        <location filename="../src/source/dialog/openwithdialog/openwithdialog.cpp" line="301"/>
        <source>Set as default</source>
        <translation>Caktoje si parazgjedhje</translation>
    </message>
    <message>
        <location filename="../src/source/dialog/openwithdialog/openwithdialog.cpp" line="303"/>
        <source>Cancel</source>
        <comment>button</comment>
        <translation>Anuloje</translation>
    </message>
    <message>
        <location filename="../src/source/dialog/openwithdialog/openwithdialog.cpp" line="304"/>
        <source>Confirm</source>
        <comment>button</comment>
        <translation>Ripohojeni</translation>
    </message>
    <message>
        <location filename="../src/source/dialog/openwithdialog/openwithdialog.cpp" line="308"/>
        <source>Recommended Applications</source>
        <translation>Aplikacione të Rekomanduar</translation>
    </message>
    <message>
        <location filename="../src/source/dialog/openwithdialog/openwithdialog.cpp" line="310"/>
        <source>Other Applications</source>
        <translation>Aplikacione të Tjera</translation>
    </message>
</context>
<context>
    <name>PasswordNeededQuery</name>
    <message>
        <location filename="../3rdparty/interface/queries.cpp" line="394"/>
        <source>Encrypted file, please enter the password</source>
        <translation>Kartelë e fshehtëzuar, ju lutemi, jepni fjalëkalimin</translation>
    </message>
</context>
<context>
    <name>PreviousLabel</name>
    <message>
        <location filename="../src/source/tree/treeheaderview.cpp" line="52"/>
        <source>Current path:</source>
        <translation>Shtegu i tanishëm:</translation>
    </message>
    <message>
        <location filename="../src/source/tree/treeheaderview.cpp" line="60"/>
        <source>Back to: %1</source>
        <translation>Mbrapsht te: %1</translation>
    </message>
</context>
<context>
    <name>ProgressDialog</name>
    <message>
        <location filename="../src/source/dialog/progressdialog.cpp" line="52"/>
        <source>%1 task(s) in progress</source>
        <translation>%1 punë(ra) në ecuri e sipër</translation>
    </message>
    <message>
        <location filename="../src/source/dialog/progressdialog.cpp" line="59"/>
        <location filename="../src/source/dialog/progressdialog.cpp" line="102"/>
        <source>Task</source>
        <translation>Punë</translation>
    </message>
    <message>
        <location filename="../src/source/dialog/progressdialog.cpp" line="65"/>
        <location filename="../src/source/dialog/progressdialog.cpp" line="113"/>
        <source>Extracting</source>
        <translation>Po përftohet</translation>
    </message>
    <message>
        <location filename="../src/source/dialog/progressdialog.cpp" line="192"/>
        <source>Are you sure you want to stop the extraction?</source>
        <translation>Jeni i sigurt se dëshironi të ndalet përftimi?</translation>
    </message>
    <message>
        <location filename="../src/source/dialog/progressdialog.cpp" line="194"/>
        <source>Cancel</source>
        <comment>button</comment>
        <translation>Anuloje</translation>
    </message>
    <message>
        <location filename="../src/source/dialog/progressdialog.cpp" line="194"/>
        <source>Confirm</source>
        <comment>button</comment>
        <translation>Ripohojeni</translation>
    </message>
</context>
<context>
    <name>ProgressPage</name>
    <message>
        <location filename="../src/source/page/progresspage.cpp" line="52"/>
        <location filename="../src/source/page/progresspage.cpp" line="314"/>
        <location filename="../src/source/page/progresspage.cpp" line="317"/>
        <location filename="../src/source/page/progresspage.cpp" line="320"/>
        <source>Speed</source>
        <comment>compress</comment>
        <translation>Shpejtësi</translation>
    </message>
    <message>
        <location filename="../src/source/page/progresspage.cpp" line="52"/>
        <location filename="../src/source/page/progresspage.cpp" line="54"/>
        <location filename="../src/source/page/progresspage.cpp" line="56"/>
        <location filename="../src/source/page/progresspage.cpp" line="60"/>
        <location filename="../src/source/page/progresspage.cpp" line="63"/>
        <location filename="../src/source/page/progresspage.cpp" line="149"/>
        <source>Calculating...</source>
        <translation>Po llogariten…</translation>
    </message>
    <message>
        <location filename="../src/source/page/progresspage.cpp" line="54"/>
        <location filename="../src/source/page/progresspage.cpp" line="324"/>
        <location filename="../src/source/page/progresspage.cpp" line="326"/>
        <source>Speed</source>
        <comment>delete</comment>
        <translation>Shpejtësi</translation>
    </message>
    <message>
        <location filename="../src/source/page/progresspage.cpp" line="56"/>
        <location filename="../src/source/page/progresspage.cpp" line="338"/>
        <location filename="../src/source/page/progresspage.cpp" line="340"/>
        <location filename="../src/source/page/progresspage.cpp" line="342"/>
        <source>Speed</source>
        <comment>convert</comment>
        <translation>Shpejtësi</translation>
    </message>
    <message>
        <location filename="../src/source/page/progresspage.cpp" line="60"/>
        <location filename="../src/source/page/progresspage.cpp" line="330"/>
        <location filename="../src/source/page/progresspage.cpp" line="332"/>
        <location filename="../src/source/page/progresspage.cpp" line="334"/>
        <source>Speed</source>
        <comment>uncompress</comment>
        <translation>Shpejtësi</translation>
    </message>
    <message>
        <location filename="../src/source/page/progresspage.cpp" line="63"/>
        <location filename="../src/source/page/progresspage.cpp" line="310"/>
        <source>Time left</source>
        <translation>Kohë e mbetur</translation>
    </message>
    <message>
        <location filename="../src/source/page/progresspage.cpp" line="122"/>
        <source>Compressing</source>
        <translation>Po ngjishen</translation>
    </message>
    <message>
        <location filename="../src/source/page/progresspage.cpp" line="124"/>
        <source>Deleting</source>
        <translation>Po fshihet</translation>
    </message>
    <message>
        <location filename="../src/source/page/progresspage.cpp" line="126"/>
        <source>Converting</source>
        <translation>Po shndërrohet</translation>
    </message>
    <message>
        <location filename="../src/source/page/progresspage.cpp" line="128"/>
        <location filename="../src/source/page/progresspage.cpp" line="147"/>
        <source>Updating the comment...</source>
        <translation>Po përditësohet komenti…</translation>
    </message>
    <message>
        <location filename="../src/source/page/progresspage.cpp" line="130"/>
        <source>Extracting</source>
        <translation>Po përftohet</translation>
    </message>
    <message>
        <location filename="../src/source/page/progresspage.cpp" line="141"/>
        <location filename="../src/source/page/progresspage.cpp" line="178"/>
        <location filename="../src/source/page/progresspage.cpp" line="358"/>
        <source>Pause</source>
        <comment>button</comment>
        <translation>Pushim</translation>
    </message>
    <message>
        <location filename="../src/source/page/progresspage.cpp" line="177"/>
        <location filename="../src/source/page/progresspage.cpp" line="387"/>
        <source>Cancel</source>
        <comment>button</comment>
        <translation>Anuloje</translation>
    </message>
    <message>
        <location filename="../src/source/page/progresspage.cpp" line="354"/>
        <source>Continue</source>
        <comment>button</comment>
        <translation>Vazhdo</translation>
    </message>
    <message>
        <location filename="../src/source/page/progresspage.cpp" line="387"/>
        <source>Confirm</source>
        <comment>button</comment>
        <translation>Ripohojeni</translation>
    </message>
    <message>
        <location filename="../src/source/page/progresspage.cpp" line="376"/>
        <source>Are you sure you want to stop the decompression?</source>
        <translation>Jeni i sigurt se doni të ndalet çngjeshja?</translation>
    </message>
    <message>
        <location filename="../src/source/page/progresspage.cpp" line="378"/>
        <source>Are you sure you want to stop the deletion?</source>
        <translation>Jeni i sigurt se doni të ndalet fshirja?</translation>
    </message>
    <message>
        <location filename="../src/source/page/progresspage.cpp" line="374"/>
        <location filename="../src/source/page/progresspage.cpp" line="380"/>
        <source>Are you sure you want to stop the compression?</source>
        <translation>Jeni i sigurt se dëshironi të ndalet ngjeshja?</translation>
    </message>
    <message>
        <location filename="../src/source/page/progresspage.cpp" line="382"/>
        <source>Are you sure you want to stop the conversion?</source>
        <translation>Jeni i sigurt se doni të ndalet shndërrimi?</translation>
    </message>
</context>
<context>
    <name>QObject</name>
    <message>
        <location filename="../src/source/tree/datamodel.h" line="71"/>
        <source>Name</source>
        <translation>Emër</translation>
    </message>
    <message>
        <location filename="../src/source/tree/datamodel.h" line="71"/>
        <source>Time modified</source>
        <translation>Kohë ndryshimi</translation>
    </message>
    <message>
        <location filename="../src/source/tree/datamodel.h" line="71"/>
        <source>Type</source>
        <translation>Lloj</translation>
    </message>
    <message>
        <location filename="../src/source/tree/datamodel.h" line="71"/>
        <source>Size</source>
        <translation>Madhësi</translation>
    </message>
    <message>
        <location filename="../src/source/mainwindow.cpp" line="2821"/>
        <source>%1 changed. Do you want to save changes to the archive?</source>
        <translation>%1 ndryshoi. Doni të ruhen ndryshimet te arkivi?</translation>
    </message>
    <message>
        <location filename="../src/source/dialog/settings_translation.cpp" line="26"/>
        <source>General</source>
        <translation>Të përgjithshme</translation>
    </message>
    <message>
        <location filename="../src/source/dialog/settings_translation.cpp" line="27"/>
        <source>Extraction</source>
        <translation>Përftim</translation>
    </message>
    <message>
        <location filename="../src/source/dialog/settings_translation.cpp" line="28"/>
        <source>Auto create a folder for multiple extracted files</source>
        <translation>Vetëkrijo një dosje për kartela të shumta të përftuara</translation>
    </message>
    <message>
        <location filename="../src/source/dialog/settings_translation.cpp" line="29"/>
        <source>Show extracted files when completed</source>
        <translation>Shfaqi kartelat e përftuara, kur të plotësohet</translation>
    </message>
    <message>
        <location filename="../src/source/dialog/settings_translation.cpp" line="30"/>
        <source>File Management</source>
        <translation>Administrim Kartelash</translation>
    </message>
    <message>
        <location filename="../src/source/dialog/settings_translation.cpp" line="31"/>
        <source>Delete files after compression</source>
        <translation>Fshiji kartelat pas ngjeshjes</translation>
    </message>
    <message>
        <location filename="../src/source/dialog/settings_translation.cpp" line="32"/>
        <source>Files Associated</source>
        <translation>Kartela të Përshoqëruara</translation>
    </message>
    <message>
        <location filename="../src/source/dialog/settings_translation.cpp" line="33"/>
        <source>File Type</source>
        <translation>Lloj Kartele</translation>
    </message>
    <message>
        <location filename="../src/source/dialog/popupdialog.cpp" line="202"/>
        <location filename="../src/source/dialog/popupdialog.cpp" line="208"/>
        <location filename="../3rdparty/interface/queries.cpp" line="244"/>
        <source>Skip</source>
        <comment>button</comment>
        <translation>Anashkaloje</translation>
    </message>
    <message>
        <location filename="../src/source/dialog/popupdialog.cpp" line="203"/>
        <source>Merge</source>
        <comment>button</comment>
        <translation>Përzieji</translation>
    </message>
    <message>
        <location filename="../src/source/dialog/popupdialog.cpp" line="206"/>
        <location filename="../3rdparty/interface/queries.cpp" line="221"/>
        <source>Another file with the same name already exists, replace it?</source>
        <translation>Ka tashmë një kartelë me po atë emër, të zëvendësohet?</translation>
    </message>
    <message>
        <location filename="../src/source/dialog/popupdialog.cpp" line="209"/>
        <location filename="../3rdparty/interface/queries.cpp" line="245"/>
        <source>Replace</source>
        <comment>button</comment>
        <translation>Zëvendësoje</translation>
    </message>
    <message>
        <location filename="../src/source/dialog/popupdialog.cpp" line="477"/>
        <location filename="../3rdparty/interface/queries.cpp" line="405"/>
        <source>Cancel</source>
        <comment>button</comment>
        <translation>Anuloje</translation>
    </message>
    <message>
        <location filename="../src/source/dialog/popupdialog.cpp" line="478"/>
        <location filename="../3rdparty/interface/queries.cpp" line="406"/>
        <source>OK</source>
        <comment>button</comment>
        <translation>OK</translation>
    </message>
    <message>
        <location filename="../src/source/dialog/popupdialog.cpp" line="200"/>
        <source>Another folder with the same name already exists, replace it?</source>
        <translation>Ka tashmë një dosje me të njëjtin emër, të zëvendësohet?</translation>
    </message>
    <message>
        <location filename="../src/source/dialog/popupdialog.cpp" line="212"/>
        <location filename="../3rdparty/interface/queries.cpp" line="226"/>
        <source>Apply to all</source>
        <translation>Zbatoje për të tëra</translation>
    </message>
</context>
<context>
    <name>SettingDialog</name>
    <message>
        <location filename="../src/source/dialog/settingdialog.cpp" line="166"/>
        <location filename="../src/source/dialog/settingdialog.cpp" line="195"/>
        <source>Current directory</source>
        <translation>Drejtoria e tanishme</translation>
    </message>
    <message>
        <location filename="../src/source/dialog/settingdialog.cpp" line="125"/>
        <source>Clear All</source>
        <translation>Spastroji Krejt</translation>
    </message>
    <message>
        <location filename="../src/source/dialog/settingdialog.cpp" line="124"/>
        <source>Select All</source>
        <comment>button</comment>
        <translation>Përzgjidhi Krejt</translation>
    </message>
    <message>
        <location filename="../src/source/dialog/settingdialog.cpp" line="126"/>
        <source>Recommended</source>
        <translation>E këshilluar</translation>
    </message>
    <message>
        <location filename="../src/source/dialog/settingdialog.cpp" line="160"/>
        <source>Extract archives to</source>
        <translation>Përftoji arkivat te</translation>
    </message>
    <message>
        <location filename="../src/source/dialog/settingdialog.cpp" line="166"/>
        <location filename="../src/source/dialog/settingdialog.cpp" line="205"/>
        <source>Other directory</source>
        <translation>Drejtori tjetër</translation>
    </message>
    <message>
        <location filename="../src/source/dialog/settingdialog.cpp" line="166"/>
        <location filename="../src/source/dialog/settingdialog.cpp" line="200"/>
        <source>Desktop</source>
        <translation>Desktop</translation>
    </message>
    <message>
        <location filename="../src/source/dialog/settingdialog.cpp" line="272"/>
        <source>Delete archives after extraction</source>
        <translation>Fshiji arkivat pas përftimit</translation>
    </message>
    <message>
        <location filename="../src/source/dialog/settingdialog.cpp" line="278"/>
        <location filename="../src/source/dialog/settingdialog.cpp" line="299"/>
        <source>Never</source>
        <translation>Kurrë</translation>
    </message>
    <message>
        <location filename="../src/source/dialog/settingdialog.cpp" line="278"/>
        <location filename="../src/source/dialog/settingdialog.cpp" line="302"/>
        <source>Ask for confirmation</source>
        <translation>Kërko ripohim</translation>
    </message>
    <message>
        <location filename="../src/source/dialog/settingdialog.cpp" line="278"/>
        <location filename="../src/source/dialog/settingdialog.cpp" line="305"/>
        <source>Always</source>
        <translation>Përherë</translation>
    </message>
</context>
<context>
    <name>SuccessPage</name>
    <message>
        <location filename="../src/source/page/successpage.cpp" line="79"/>
        <source>Compression successful</source>
        <translation>Ngjeshje e suksesshme</translation>
    </message>
    <message>
        <location filename="../src/source/page/successpage.cpp" line="89"/>
        <source>View</source>
        <translation>Shihni</translation>
    </message>
    <message>
        <location filename="../src/source/page/successpage.cpp" line="92"/>
        <source>Back</source>
        <translation>Mbrapsht</translation>
    </message>
</context>
<context>
    <name>UnCompressPage</name>
    <message>
        <location filename="../src/source/page/uncompresspage.cpp" line="75"/>
        <location filename="../src/source/page/uncompresspage.cpp" line="87"/>
        <location filename="../src/source/page/uncompresspage.cpp" line="116"/>
        <source>Extract to:</source>
        <translation>Përftoji te:</translation>
    </message>
    <message>
        <location filename="../src/source/page/uncompresspage.cpp" line="117"/>
        <source>Extract</source>
        <comment>button</comment>
        <translation>Përftoji</translation>
    </message>
    <message>
        <location filename="../src/source/page/uncompresspage.cpp" line="191"/>
        <source>The default extraction path does not exist, please retry</source>
        <translation>Shtegu parazgjedhje i përftimeve s’ekziston, ju lutemi, riprovoni</translation>
    </message>
    <message>
        <location filename="../src/source/page/uncompresspage.cpp" line="193"/>
        <source>You do not have permission to save files here, please change and retry</source>
        <translation>S’keni leje të ruani kartela këtu, ju lutemi, ndryshoni lejet dhe riprovoni</translation>
    </message>
    <message>
        <location filename="../src/source/page/uncompresspage.cpp" line="197"/>
        <source>OK</source>
        <comment>button</comment>
        <translation>OK</translation>
    </message>
    <message>
        <location filename="../src/source/page/uncompresspage.cpp" line="211"/>
        <source>Find directory</source>
        <translation>Gjej drejtori</translation>
    </message>
</context>
<context>
    <name>UnCompressView</name>
    <message>
        <location filename="../src/source/tree/uncompressview.cpp" line="392"/>
        <source>You cannot add the archive to itself</source>
        <translation>S’mund ta shtoni arkivin te vetvetja</translation>
    </message>
    <message>
        <location filename="../src/source/tree/uncompressview.cpp" line="392"/>
        <source>OK</source>
        <comment>button</comment>
        <translation>OK</translation>
    </message>
    <message>
        <location filename="../src/source/tree/uncompressview.cpp" line="618"/>
        <source>Extract</source>
        <comment>提取</comment>
        <translation>Përftoji</translation>
    </message>
    <message>
        <location filename="../src/source/tree/uncompressview.cpp" line="620"/>
        <source>Extract to current directory</source>
        <translation>Përftoji te drejtoria e tanishme</translation>
    </message>
    <message>
        <location filename="../src/source/tree/uncompressview.cpp" line="622"/>
        <source>Open</source>
        <translation>Përzgjidhni kartelën</translation>
    </message>
    <message>
        <location filename="../src/source/tree/uncompressview.cpp" line="625"/>
        <source>Delete</source>
        <translation>Fshije</translation>
    </message>
    <message>
        <location filename="../src/source/tree/uncompressview.cpp" line="632"/>
        <source>Open with</source>
        <translation>Hape me</translation>
    </message>
    <message>
        <location filename="../src/source/tree/uncompressview.cpp" line="636"/>
        <location filename="../src/source/tree/uncompressview.cpp" line="737"/>
        <source>Select default program</source>
        <translation>Përzgjidhni program parazgjedhje</translation>
    </message>
    <message>
        <location filename="../src/source/tree/uncompressview.cpp" line="687"/>
        <source>Cancel</source>
        <comment>button</comment>
        <translation>Anuloje</translation>
    </message>
    <message>
        <location filename="../src/source/tree/uncompressview.cpp" line="687"/>
        <source>Confirm</source>
        <comment>button</comment>
        <translation>Ripohojeni</translation>
    </message>
    <message>
        <location filename="../src/source/tree/uncompressview.cpp" line="687"/>
        <source>Do you want to delete the selected file(s)?</source>
        <translation>Doni të fshihet kartelat(t) e përzgjedhur?</translation>
    </message>
</context>
</TS>
